/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VShortArray;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsShort;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeShort;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVShortArray;

/**
 * Type adapter that convert from {@link ChannelAccessControlsShort} and
 * {@link ChannelAccessTimeShort} to {@link VShortArray}.
 * 
 * @author Sebastian Marsching
 */
public class ArrayShortTypeAdapter
        extends JackieDataSourceTypeAdapter<VShortArray> {

    /**
     * Single instance of this adapter.
     */
    public static final ArrayShortTypeAdapter INSTANCE = new ArrayShortTypeAdapter();

    private ArrayShortTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_SHORT, VShortArray.class);
    }

    @Override
    protected VShortArray convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_SHORT and we thus know that the
        // monitors return a DBR_CTRL_SHORT and DBR_TIME_SHORT.
        ChannelAccessControlsShort controlsValue = (ChannelAccessControlsShort) message
                .getControlsValue();
        ChannelAccessTimeShort timeValue = (ChannelAccessTimeShort) message
                .getTimeValue();
        return new JackieVShortArray(controlsValue, timeValue,
                connection.getDisconnectTime());
    }

}
